@@ -1,4 +1,4 @@
-## version: 1.38
+## version: 1.36
 ## method: get
 ## path: /configs/{id}
 ## code: 200
@@ -15,5 +15,4 @@ list(
     ## https://docs.docker.com/engine/api/v1.30/#operation/ConfigInspect
     ## the 'data' element is not returned, which is not consistent
     ## with the spec.
-    data = "VEhJUyBJUyBOT1QgQSBSRUFMIENFUlRJRklDQVRFCg==",
-    templating = NULL))
+    data = "VEhJUyBJUyBOT1QgQSBSRUFMIENFUlRJRklDQVRFCg=="))
